package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@("`0`````````````#`!8````!````````)3@`````````0```````
M`+18``````!``#@`"0!``!L`&@````8````%`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*CD````````J.0`
M```````0``````$````&````````K>@```````"]Z````````+WH````````
M!3`````````58````````!```````@````8```````"N`````````+X`````
M````O@`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````HKP```````"BO````````**\`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*WH````````O>@`````
M``"]Z`````````(8`````````A@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````(````&````(`````0````4`````T=.
M50!KQV^=UG#T-8`O77DW,GB;X\)CA``````````1````2@````0````(A`1`
M!0`0$""``(:````"*`D$(`D``"F""`($ND48H(@`````````2@```$X```!2
M````4P```%D```!:````6P```%T```!>`````````&````!A````8@```&,`
M`````````!_?Q6X.[]/J+4?>SGR:?VNVF\4N#N3_(`[QC;A\U&35'%AQV0'&
M1^+`XTNL?)+CNBP_Y<)@;*'Z;XL!L]9#"6MFS*]G[-5%0M-P!XF>XA0-GN/-
MVNW;8C,+ESH-FYRI?PH"I^%)^^"C````````````````````````````````
M```````````#```+````````&U@``````````````HD2````````````````
M`````````````Q(B`````````````````````````````=L2````````````
M`````````````````!$@`````````````````````````````U`1````````
M`````````````````````Z42`````````````````````````````M81````
M`````````````````````````R\2`````````````````````````````1D2
M`````````````````````````````J02````````````````````````````
M`+P2`````````````````````````````NT2````````````````````````
M`````8L2`````````````````````````````I`2````````````````````
M`````````)@2`````````````````````````````102````````````````
M`````````````DX2`````````````````````````````MT2````````````
M`````````````````0D1`````````````````````````````FP2````````
M`````````````````````6\2`````````````````````````````.L1````
M`````````````````````````3T2`````````````````````````````,H2
M`````````````````````````````;D2````````````````````````````
M`N02`````````````````````````````AT2````````````````````````
M`````?$2`````````````````````````````:82````````````````````
M`````````GL2`````````````````````````````E\2````````````````
M`````````````;(2`````````````````````````````4L2````````````
M`````````````````O02`````````````````````````````"T@````````
M`````````````````````B\2`````````````````````````````P$2````
M`````````````````````````'@2`````````````````````````````SX2
M`````````````````````````````=02````````````````````````````
M`>`2`````````````````````````````R$2````````````````````````
M`````*<2`````````````````````````````602````````````````````
M`````````F82`````````````````````````````CP2````````````````
M`````````````2H2`````````````````````````````G02````````````
M`````````````````&H2`````````````````````````````1X2````````
M`````````````````````JL2`````````````````````````````9L2````
M`````````````````````````I82`````````````````````````````/@2
M`````````````````````````````S<2````````````````````````````
M`H(2`````````````````````````````U$A````````````````````````
M`````7T2`````````````````````````````(<2````````````````````
M`````````#P@`````````````````````````````-P2````````````````
M`````````````5L2`````````````````````````````P@2````````````
M`````````````````C02`````````````````````````````%`@````````
M`````````````````````U(1`````````````````````````````LP2````
M`````````````````````````?D2`````````````````````````````KD2
M`````````````````````````````D42````````````````````````````
M`@T2`````````````````````````````L02````````````````````````
M`````ZX2```-````````8!``````````F@```WP2```.````````85@`````
M`````````],2```-````````4*@````````+&````TL2```-````````(M@`
M```````"7````X(2```-````````2.``````````!@``!$$2```-````````
M2.@````````"'```!#L2```+````````&U@`````````````!&X2```-````
M````6\`````````$3@```V$0```8````````PQ@``````````````[H2```-
M````````2P@`````````-````^T1```/````````88@`````````!````VT0
M```8````````TT@`````````````!#D2```-````````1U``````````/@``
M!$X2```-````````3U@````````!3@``!&`2```-````````3G@`````````
MH````^`0```7````````PF```````````````\<2```-````````2T``````
M```!6@```UH0```7````````PQ@`````````````!"(1```7````````PQ``
M````````"````W(2```-````````85```````````@``!!(2```-````````
M8.@`````````9````^82```-````````)3@``````````````^(@```7````
M````PF```````````````Y,2```-````````3Q@`````````.@```_P2```-
M````````1_``````````\```!"P2```-````````3*`````````!U`!L:6)P
M97)L+G-O+C4N,C(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO
M;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E
M='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y
M`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;&EB
M<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E
M96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E
M9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`
M7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`
M9V5T<&ED`'-T<G1O:P!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC
M<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T
M`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S
M=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`
M;65M;6]V90!A8V-E<W,`7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E
M9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R
M<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D
M871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I
M;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L
M96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXS
M+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````````@`"``,````"``(``@`"
M``(``@````(````"```````$``(````"```````````````"``4``P````(`
M`@`"````!@````(``@````(``P`#``0```````(``@````(```````8````$
M`````@`"``(```````````````(``@````(``@`#``(``@`#``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0```<0````0````(`UI:1(````#```$A````````0`$```"$P```!``
M````"6D9=`````8```2.````$`EI&7(````%```$F@```!`-:6D4````!```
M!*8````0#6EI$@````(```2$`````````````+WH``````````P````````F
M2````````+WP``````````P````````E^````````,(X``````````P`````
M```BV````````,)H``````````P```````#":````````,)P``````````P`
M``````!C.@```````,)X``````````P```````!C(@```````,*`````````
M``P```````!C*@```````,*(``````````P```````!C4````````,*0````
M``````P```````!C.````````,*8``````````P```````!C2@```````,*H
M``````````P```````!D0````````,*P``````````P```````!B,```````
M`,+```````````P```````!BY@```````,+(``````````P```````!BZ@``
M`````,+0``````````P```````!D1@```````,+8``````````P```````!B
M-@```````,+@``````````P```````!D3@```````,+P``````````P`````
M``!D4@```````,+X``````````P```````!D6````````,,0``````````P`
M``````!E!@```````,'@`````P````H``````````````````,'H````!0``
M``H``````````````````,'P````"`````H``````````````````,'X````
M#@````H``````````````````,(`````%`````H``````````````````,((
M````%P````H``````````````````,(0````'`````H`````````````````
M`,(8````)`````H``````````````````,(@````+0````H`````````````
M`````,(H````+P````H``````````````````,(P````,`````H`````````
M`````````,)`````/`````H``````````````````,)(````/0````H`````
M`````````````,)0````0@````H``````````````````,)8````0P````H`
M`````````````````,`8`````@````L``````````````````,`@`````P``
M``L``````````````````,`H````!`````L``````````````````,`P````
M!P````L``````````````````,`X````"0````L``````````````````,!`
M````"@````L``````````````````,!(````"P````L`````````````````
M`,!0````#`````L``````````````````,!8````#0````L`````````````
M`````,!@````#P````L``````````````````,!H````$`````L`````````
M`````````,!P````$0````L``````````````````,!X````$@````L`````
M`````````````,"`````$P````L``````````````````,"(````%0````L`
M`````````````````,"0````%@````L``````````````````,"8````&```
M``L``````````````````,"@````&0````L``````````````````,"H````
M&@````L``````````````````,"P````&P````L``````````````````,"X
M````'0````L``````````````````,#`````'@````L`````````````````
M`,#(````'P````L``````````````````,#0````(`````L`````````````
M`````,#8````(0````L``````````````````,#@````(@````L`````````
M`````````,#H````(P````L``````````````````,#P````)0````L`````
M`````````````,#X````)@````L``````````````````,$`````)P````L`
M`````````````````,$(````*`````L``````````````````,$0````*0``
M``L``````````````````,$8````*@````L``````````````````,$@````
M*P````L``````````````````,$H````+`````L``````````````````,$P
M````+@````L``````````````````,$X````+P````L`````````````````
M`,%`````,0````L``````````````````,%(````,@````L`````````````
M`````,%0````,P````L``````````````````,%8````-`````L`````````
M`````````,%@````-0````L``````````````````,%H````-@````L`````
M`````````````,%P````-P````L``````````````````,%X````.`````L`
M`````````````````,&`````.0````L``````````````````,&(````.P``
M``L``````````````````,&0````/@````L``````````````````,&8````
M/P````L``````````````````,&@````0`````L``````````````````,&H
M````00````L``````````````````,&P````1`````L`````````````````
M`,&X````10````L``````````````````,'`````1@````L`````````````
M`````,'(````1P````L``````````````````,'0````2`````L`````````
M`````````,'8````20````L``````````.MO\#``)+D$`!^G^_]@XQ#P```D
MP,```%)*P!```%-3XQ`0```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T!P?C
M$/`X`"3`$```4C'2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!2,.,0$```!`?Q
M#1#C$!`,`!3`]/___^4`````P!```%(DXQ`0```$!_$-$.,0$`P`%,#T____
MU0```!C`$```4ACC$!````0'\0T0XQ`0#``4P/3____%````,,`0``!2#.,0
M$```!`?Q#1#C$!`,`!3`]/___[4```!(P!```%(`XQ`0```$!_$-$.,0$`P`
M%,#T____I0```&#`$```4?3C$!````0'\0T0XQ`0#``4P/3___^5````>,`0
M``!1Z.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```%'<XQ`0```$!_$-
M$.,0$`P`%,#T____=0```*C`$```4=#C$!````0'\0T0XQ`0#``4P/3___]E
M````P,`0``!1Q.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```%&XXQ`0
M```$!_$-$.,0$`P`%,#T____10```/#`$```4:SC$!````0'\0T0XQ`0#``4
MP/3___\U```!",`0``!1H.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!``
M`%&4XQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```48CC$!````0'\0T0
MXQ`0#``4P/3___\%```!4,`0``!1?.,0$```!`?Q#1#C$!`,`!3`]/___O4`
M``%HP!```%%PXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```463C$!``
M``0'\0T0XQ`0#``4P/3___[5```!F,`0``!16.,0$```!`?Q#1#C$!`,`!3`
M]/___L4```&PP!```%%,XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```
M44#C$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!1-.,0$```!`?Q#1#C
M$!`,`!3`]/___I4```'XP!```%$HXQ`0```$!_$-$.,0$`P`%,#T___^A0``
M`A#`$```41SC$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!1$.,0$```
M!`?Q#1#C$!`,`!3`]/___F4```)`P!```%$$XQ`0```$!_$-$.,0$`P`%,#T
M___^50```EC`$```4/CC$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!0
M[.,0$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```%#@XQ`0```$!_$-$.,0
M$`P`%,#T___^)0```J#`$```4-3C$!````0'\0T0XQ`0#``4P/3___X5```"
MN,`0``!0R.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```%"\XQ`0```$
M!_$-$.,0$`P`%,#T___]]0```NC`$```4+#C$!````0'\0T0XQ`0#``4P/3_
M__WE```#`,`0``!0I.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```%"8
MXQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`$```4(SC$!````0'\0T0XQ`0
M#``4P/3___VU```#2,`0``!0@.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@
MP!```%!TXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```4&CC$!````0'
M\0T0XQ`0#``4P/3___V%```#D,`0``!07.,0$```!`?Q#1#C$!`,`!3`]/__
M_74```.HP!```%!0XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```4$3C
M$!````0'\0T0XQ`0#``4P/3___U5```#V,`0``!0..,0$```!`?Q#1#C$!`,
M`!3`]/___44```/PP!```%`LXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`
M$```4"#C$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!0%.,0$```!`?Q
M#1#C$!`,`!3`]/___14```0XP!```%`(XQ`0```$!_$-$.,0$`P`%,#T___]
M!0``!%#`$```3_SC$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!/\.,0
M$```!`?Q#1#C$!`,`!3`]/___.4```2`P!```$_DXQ`0```$!_$-$.,0$`P`
M%,#T___\U0``!)C`$```3]CC$!````0'\0T0XQ`0#``4P/3___S%```$L,`0
M``!/S.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$_`XQ`0```$!_$-
M$.,0$`P`%,#T___\I0``!.#`$```3[3C$!````0'\0T0XQ`0#``4P/3___R5
M```$^,`0``!/J.,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!```$^<XQ`0
M```$!_$-$.,0$`P`%,#T___\=0``!2C`$```3Y#C$!````0'\0T0XQ`0#``4
MP/3___QE```%0.MO\#``)+)/`!#K$0`@``VR3P`1X_#_./]QXS#PJ``DXT#P
MH``D4"#PM$%`\*#2!_#`$"A!,/"H02#PM,#E___^(L1(``!/B\0H``!/D+D$
M`#3`Y0``'L/$&```3VR5`!``IX0`ML38``!/8>,@T```%L#E____=Y8")1+C
M(-```!;`Y?___V]8$/"TIQH`!98!)1*Y%``AZR(``P`-P.7___UQP!```%?:
MY4P0```$P!```""[XS#PJ``$XT`P```$XQ`@"``DXT`@```DQ!@``$^UXQ`@
M$``DQ"L``%>[P!```""EXQ`@&``D6$#PM.Q,`!L!?D$P,`BG"``%[%3__P#8
MN10`$..P,```!.L1``,`#>.Q+_C_)*<*``&G.P`(IU;_\>P4``0`V+D4`!'K
M$0`#``WC$2_X_W&Y!`!2ITH``Z=I``"Y%`!$Y4@0````P#```!&SQ"@``%>(
MP.7___Y1&-+L*`!-`'[$*```5WY!L/"\P.7___REN00`.\`@```?%<#E```-
MJ>PH`$,`?,0H``!7:\#E___\5,#E___^`;)/`!#K$0`@``VR3P`1N10`+=4'
M\,`0**=T`$WC0/$X``3K;_#X``0'],#E___\J<0K``!72NPH`#D`?,#E___\
M(,38``!.H>,@T```%L#E___^MY(`*16G]/\XQ"@``%<TP.7___YM&-*G]/^O
MP!```%<GXR`0```"IX0`!\#E```=BZ?T_[6Y!``[P"```!Z5P.4```U1Q"L`
M`%<2["C_J`!\I_3_[:<I``'`Y?___/C`Y?___`4'!P<'04#P".,P\```!*<)
M__"Y@`#PI_O_4-<'\`#P`.OO\*``)$%P\*#`8```'?G`4```'<+`(```3F?C
M("````3`Y?___0$```<'P!```$[,P#```$[)02`0![GI,!+L'``,#GW$&```
M3B?L&``&`'RY!``C!_$'_@<'P"```$ZTP!```$ZQN>D0$NL1``,`"NLQ`#\`
M#+D(`#'K,P`!``KL.``-`'S$&```3CKL&``'`'S`(```3I@'\0?^!P<'!P<'
MZ]_P:``DP-```$Z-X_#_8/]QE0#0`*=T`!7`$```3>?C$!````*GA``(Q"@`
M`$XCP.7___K8P.7___^ID@'0`.-`\1``!.O?\0@`!`?T!P?`(```2]CC$"``
M``*G=``%P/3___^LQ!@``$WU[!C_^@!\Z^_P<``DX_#_8/]Q#>'K[_$0``3`
M]/___YD'!P<'ZV_P,``DLD\`$./P_-C_<>L1`"``#;)/`!%!,/"@T@?S(!`H
M05`@.*=)``CC$%````3K`0`@``SC`#```"3`&@````#C$#`(`"1!4%`(ISL`
M$*='_^U!$/$(ITD`0.,P$```!.,P']C_@N,P'ZC_@N,P'YC_@NQ3(+]A6>Q3
M(#X!5N-0$!@`)*<;``BG1__IXS`@```$XU`@(``$[!,@OV59XU#PH``([!,@
M.@56PEI:@GF9N>A00>.P(!``!..0(`@`!..@(!@`!.L)`!X`#;GGH!OK60`"
M``RY@``9N8$`4+F"`!KK8P`>``VY"``4ZT,``@`,['$@OP!5N8$`9+GG8-6Y
M@``=N8(`%>P%(+\`5>N'`!X`#;D$`$OK5P`;``SC0/"P``CL5R`Z!5;"2EJ"
M>9GK=P`"``RY&@!!N><`&[F``!.Y@@`;N00`VN/0\*@`",+:6H)YF;D(`-&Y
MYG`8XX#PN``$N><0=L**6H)YF;D(`%VY"``([-4@OP!5N8``5^N-`!X`#;F"
M`%;K?0`;``RY&@`%['T@.@56Z]T``@`,N0@`1^QT(+\`5>M7`!L`#.Q7(#H%
M5KD(`%"YYM`(N><`@;F``$BY@@!!X]#PP``$PMI:@GF9N1H`UNQE(+\`5;D:
M`-3KA@`;``RY!`!-[(8@.@56N00`V.N'`!X`#;D(`-2SP0`HL\T`0N.`\,@`
M!,**6H)YF;D:`('K=P`"``RY!``8N8$`1[GG0(#L?2"_`%6Y@`!8ZX<`&P`,
MN8(`4.R'(#H%5KD:`!6Y!`!1N0@`6..`\-``!,**6H)YF;D:`(#K%@`>``VY
M!``(ZV8``@`,N8$`%KGG$(3L92"_`%6Y@`#8ZX8`&P`,N8(`U.R&(#H%5KD:
M``VY!`#0N0@`V..`\-@`!,**6H)YF;D:`(3K!P`>``VY!`!(ZW<``@`,N8$`
M![GG`('L?2"_`%6Y@`!8ZX<`&P`,N8(`4>R'(#H%5KD:`$6Y!`!4N0@`6..`
M\.``!,**6H)YF;D:`('K1@`>``VY!``8ZV8``@`,N8$`1KGG0(#L92"_`%6Y
M@`#8ZX8`&P`,N8(`T.R&(#H%5KD:`!VY!`#1N0@`V..`\.@`!,**6H)YF;D:
M`(#K%P`>``VY!``(ZW<``@`,N8$`%[GG$(3L?2"_`%6Y@`!8ZX<`&P`,N8(`
M5.R'(#H%5KD:``6Y!`!0N0@`6..`\/``!,**6H)YF;D:`(3K!@`>``VY!`!(
MZV8``@`,N8$`!KGG`('L92"_`%6Y@`#8ZX8`&P`,N8(`T>R&(#H%5KD:`$VY
M!`#4N0@`V..`\/@`!,**6H)YF;D:`('K1P`>``VY!``8ZW<``@`,N8$`1[GG
M0(#L?2"_`%6Y@`!8ZX<`&P`,N8(`4.R'(#H%5KD:`!6Y!`!1N0@`6..`\0``
M!,**6H)YF;D:`(#K%@`>``VY!``(ZV8``@`,N8$`%KGG$(3L92"_`%6Y@`#8
MZX8`&P`,N8(`U.R&(#H%5KD:``VY!`#0N0@`V..`\0@`!,**6H)YF;D:`(3K
M!P`>``VY!`!(ZW<``@`,N8$`![GG`('L?2"_`%6Y@`!8ZX<`&P`,N8(`4>R'
M(#H%5KD:`$6Y!`!4N0@`6..`\1``!,**6H)YF;D:`('K1@`>``VY!``8ZV8`
M`@`,N8$`1KGG0(#L92"_`%6Y@`#8ZX8`&P`,N8(`T.R&(#H%5KD:`!VY!`#1
MN0@`V..`\1@`!,**6H)YF;D:`(#K%P`>``VY!``(ZW<``@`,N8$`%[GG$(3L
M?2"_`%6Y@`!8ZX<`&P`,N8(`5.R'(#H%5KD:``6Y!`!0N0@`6..`\2``!,**
M6H)YF;D:`(3K!@`>``VY!`!(ZV8``@`,N8$`!KGG`('L92"_`%6Y@`#8ZX8`
M&P`,N8(`T>R&(#H%5KD:`$VY!`#4N0@`V..`\2@`!,**6H)YF;D:`('K1P`>
M``VY!``8ZW<``@`,N8$`1[GG0("Y@`!8N8(`4+D:`!7L?2"_`%6Y!`!1ZX<`
M&P`,[(<@.@56L\$`"+/-`!#KA@`>``VY"`!1ZQ8``@`,N8$`&+GG$(3C8/$P
M``2Y@`#8PFI:@GF9N1H`8.P%(+\`5>N``!L`#.R`(#H%5KF"`-2Y&@!MN0@`
M:..`\3@`!,**6H)YF;D:`(3KUP`>``VY!`!(ZW<``@`,N8$`U[GGT('L=B"_
M`%6Y@`!8ZX<`&P`,N8(`4>R'(#H%5KD:`$6Y!`!4N0@`6..`\4``!,**;MGK
MH;D:`('K0``>``VY!``8ZP```@`,N8$`0+GG0(VY@@"&N1H`&.N'`!X`#>P%
M(+\`5>M@`!L`#.Q@(#H%5KD(`&'K%P`"``RY@0`8N><0A+F"`%CC</%(``3"
M>F[9ZZ&Y&@!][-8@OP!5N1H`=>N-`!L`#+D$`%?LC2`Z!5:Y!`!XZX``'@`-
MN0@`=;/!`"BSS0!2XX#Q4``$PHINV>NAN1H`A.L```(`#+D$`$BY@0!0N>=0
M@;F"`(:Y&@!([`<@OP!5ZXT`'@`-ZV``&P`,L\$`*.Q@(#H%5KD(`&2SS0!"
MXX#Q6``$PHINV>NAN1H`@>O=``(`#+D$`!BY@0!-N>=`A;F"`(>Y&@`8[-8@
MOP!5ZX``'@`-ZWT`&P`,L\$`*.Q](#H%5KD(`'&SS0`2XX#Q8``$PHINV>NA
MN1H`A>L```(`#+D$`%BY@0`0N><0A+F"`(:Y&@!8[`<@OP!5ZXT`'@`-ZV``
M&P`,L\$`*.Q@(#H%5KD(`&6SS0!2XX#Q:``$PHINV>NAN1H`A.O=``(`#+D$
M`$BY@0!=N>=0@;F"`(>Y&@!([-8@OP!5ZX``'@`-ZWT`&P`,['T@.@56N0@`
M=.M```(`#.P'(+\`5;F!`$CC@/%P``3"BF[9ZZ&Y&@"!N00`&+GG0(6Y@@!H
MZXT`'@`-N1H`%K/!`"BY!`"!L\T`$NO=``(`#.-@\7@`!+F!`!W":F[9ZZ&Y
M&@!EN><05+F"`%?KT``;``RY&@!EN00`?>M0`!X`#>QP(#H%5NL```(`#+D(
M`'BY@0!0[-<@OP!5ZXT`&P`,N00`".P-(#H%5KGG4(&Y"`!@N8(`A^,`\8``
M!,(*;MGKH;D:``2Y!`!`N1H`2.QV(+\`5>N-`!X`#>L'`!L`#+/!`"CL!R`Z
M!5:Y"``$L\T`0N.`\8@`!,**;MGKH;D:`('KW0`"``RY!``8N8$`3;GG0(6Y
M@@"&N1H`&.S0(+\`5>N'`!X`#>MM`!L`#+/!`"CL;2`Z!5:Y"`!AL\T`$N.`
M\9``!,**;MGKH;D:`(7K=P`"``RY!`!8N8$`%[GG$(2Y@@"`N1H`6.QV(+\`
M5>N-`!X`#>L'`!L`#+/!`"CL!R`Z!5:Y"``%L\T`4N.`\9@`!,**;MGKH;D:
M`(3KW0`"``RY!`!(N8$`7;GG4(&Y@@"&N1H`2.S0(+\`5>N'`!X`#>MM`!L`
M#+/!`"CL;2`Z!5:Y"`!DL\T`0N.`\:``!,**;MGKH;D:`('K=P`"``RY!``8
MN8$`1[GG0(6Y@@"`N1H`&.QV(+\`5>N-`!X`#>L'`!L`#+/!`"CL!R`Z!5:Y
M"``!L\T`$N.`\:@`!,**;MGKH;D:`(7KW0`"``RY!`!8N8$`';GG$(2Y@@"&
MN1H`6.S0(+\`5>N'`!X`#>MM`!L`#+/!`"CL;2`Z!5:Y"`!EL\T`4N.`\;``
M!,**;MGKH;D:`(3K=P`"``RY!`!(N8$`5[GG4(&Y@@"`N1H`2.QV(+\`5>N-
M`!X`#>L'`!L`#+/!`"CL!R`Z!5:Y"``$L\T`0N.`\;@`!,**;MGKH;D:`('K
MW0`"``RY!``8N8$`3;GG0(6Y@@"&N1H`&.S0(+\`5>N'`!X`#>MM`!L`#+/!
M`"CL;2`Z!5:Y"`!AL\T`$N.`\<``!,**;MGKH;D:`(7K=P`"``RY!`!8N8$`
M%[GG$(2Y@@"`N1H`6.QV(+\`5>N-`!X`#>L'`!L`#+/!`"CL!R`Z!5:Y"``%
ML\T`4N.`\<@`!,**;MGKH;D:`(3KW0`"``RY!`!(N8$`7;GG4(&Y@@"&N1H`
M2.S0(+\`5>N'`!X`#>MM`!L`#+/!`"CL;2`Z!5:Y"`!DL\T`0N.`\=``!,**
M;MGKH;D:`('K=P`"``RY!``8N8$`1[GG0(6Y@@"`N1H`&.QV(+\`5>N-`!X`
M#>L'`!L`#+/!`"CL!R`Z!5:Y"``!L\T`$N.`\=@`!,**;MGKH;D:`(7KW0`"
M``RY!`!8N8$`';GG$(2Y@@"&N1H`6.S0(+\`5>N'`!X`#>MM`!L`#.QM(#H%
M5KD(`&7K5P`"``SC</'@``3">H\;O-RY&@!TN8$`6+D$`$>YY%"!N>90<;F`
M`'"Y@0"'N1H`2.P&(+\`5>N-`!X`#>MP`!L`#.QP(#H%5KD(`'3K30`"``SC
MT/'H``3"VH\;O-RY&@#1N8$`2+D$`!VYY$"%N>9`U;F``-:Y@0"-N1H`&.QG
M(+\`5>N``!X`#>O6`!L`#.S6(#H%5KD(`-'K$``"``SC`/'P``3""H\;O-RY
M&@`%N8$`&+D$`%"YY!"$N>80!+F```>Y@0"`N1H`6.Q](+\`5>N&`!X`#>L'
M`!L`#.P'(#H%5KD(``7K5@`"``SC8/'X``3":H\;O-RY&@!DN8$`6+D$`$:Y
MY%"!N>908;F``&VY@0"&N1H`2.S0(+\`5>N'`!X`#>MM`!L`#.QM(#H%5KD(
M`&3K1P`"``SC</(```3">H\;O-RY&@!QN8$`2+D$`!>YY$"%N>9`=;F``'"Y
M@0"'N1H`&.P&(+\`5>N-`!X`#>MP`!L`#.QP(#H%5KD(`''K'0`"``SCT/((
M``3"VH\;O-RY&@#5N8$`&+D$`%VYY!"$N>80U+F``-:Y@0"-N1H`6.QG(+\`
M5>N``!X`#>O6`!L`#.S6(#H%5KD(`-7K4``"``SC`/(0``3""H\;O-RY&@`$
MN8$`6+D$`$"YY%"!N>90`;F```>Y@0"`N1H`2.Q](+\`5>N&`!X`#>L'`!L`
M#.P'(#H%5KD(``3K1@`"``SC8/(8``3":H\;O-RY&@!AN8$`2+D$`!:YY$"%
MN>9`9;F``&VY@0"&N1H`&.S0(+\`5>N'`!X`#>MM`!L`#.QM(#H%5KD(`&'K
M%P`"``SC</(@``3">H\;O-RY&@!UN8$`&+D$`%>YY!"$N>80=+F``'"Y@0"'
MN1H`6.P&(+\`5>N-`!X`#>MP`!L`#.QP(#H%5KD(`'7K70`"``SCT/(H``3"
MVH\;O-RY&@#4N8$`6+D$`$VYY%"!N>90T;F``-:Y@0"-N1H`2.QG(+\`5>N`
M`!X`#>O6`!L`#.S6(#H%5KD(`-3K0``"``SC`/(P``3""H\;O-RY&@`!N8$`
M2+D$`!"YY$"%N>9`!;F```>Y@0"`N1H`&.Q](+\`5>N&`!X`#>L'`!L`#.P'
M(#H%5KD(``'K%@`"``SC8/(X``3":H\;O-RY&@!EN8$`&+D$`%:YY!"$N>80
M9+F``&VY@0"&N1H`6.S0(+\`5>MM`!L`#.QM(#H%5KD(`&7L5B"_`%7KAP`>
M``WK=P`"``RY@0!XN>9P@;F``(#K#0`>``WKW0`"``RY@0`-N>8`U[F``&VY
MY`#7N8$`;>/0\D@`!,+:CQN\W+D:`-&Y@``7N1H`UKF!`!CC8/)```3":H\;
MO-RY&@!DN00`1KD:`$'KA0`;``RY!``4[(4@.@56ZT4`'@`-ZU4``@`,N0@`
M&+F!`$7L82"_`%6YYD"`ZU8`&P`,[%8@.@56L\$`*+D$`(6SS0!2N0@`V+GD
M0("Y@`!1N8$`A>,0\E``!,(:CQN\W+D:`!>Y&@`8ZX8`'@`-ZV8``@`,[%T@
MOP!5ZW4`&P`,['4@.@56N0@`<;GF8!CC8/)8``2YYA"$PFJ/&[S<N1H`8+D$
M``:YY-!HN>00A+F!`(:Y&@`([-<@OP!5ZX4`'@`-ZVT`&P`,[&T@.@56N0@`
M8.,`\F``!,(*CQN\W+D:``3K50`"``RY!`!`N8$`6+GF4`&YY%"!N8``<+F!
M`(>Y&@!([`8@OP!5ZXT`'@`-ZW``&P`,['`@.@56N0@`=.M-``(`#./0\F@`
M!,+:CQN\W+D:`-&Y@0!(N00`';GD0(6YYD#5N8``UKF!`(VY&@`8[&<@OP!5
MZX``'@`-Z]8`&P`,[-8@.@56N0@`T>L0``(`#.,`\G``!,(*CQN\W+D:``6Y
M@0`8N00`4+GD$(2YYA`$N8``![F!`("Y&@!8ZX8`'@`-['T@OP!5ZV8``@`,
MZP<`&P`,N8$`:.P'(#H%5KGD8(&Y"``%XU#R>``$PEJ/&[S<N1H`5+GF8$&Y
M@`#4N8$`C;D:`%CL0""_`%7KAP`>``WKU``;``RSP0`H[-0@.@56N0@`U;/-
M`%+C@/*```3"BLIBP=:Y&@"!ZW<``@`,N00`&+F!`%>YYU"&N8(`@+D:`!CK
MA``>``WL?2"_`%7K1``"``SK!P`;``RY@0!([`<@.@56N>=`A;D(``&Y@@"-
MXQ#RB``$PAK*8L'6N1H`%KD:`!CL8""_`%7KAP`>``WKU@`;``RSP0`H[-8@
M.@56N0@`T;/-`!+C@/*0``3"BLIBP=:Y&@"%ZW<``@`,N00`6+F!`!>YYQ"$
MN8(`@+D:`%CL?2"_`%7KA@`>``WK!P`;``RSP0`H[`<@.@56N0@`!;/-`%+C
M@/*8``3"BLIBP=:Y&@"$ZV8``@`,N00`2+F!`%:YYU"!N8(`C;D:`$CL8""_
M`%7KAP`>``WKU@`;``RSP0`H[-8@.@56N0@`U+/-`$+C@/*@``3"BLIBP=:Y
M&@"!ZW<``@`,N00`&+F!`$>YYT"%N8(`@+D:`!CL?2"_`%7KA@`>``WK!P`;
M``RSP0`H[`<@.@56N0@``;/-`!+C@/*H``3"BLIBP=:Y&@"%ZV8``@`,N00`
M6+F!`!:YYQ"$N8(`C;D:`%CL8""_`%7KAP`>``WKU@`;``RSP0`H[-8@.@56
MN0@`U;/-`%+C@/*P``3"BLIBP=:Y&@"$ZW<``@`,N00`2+F!`%>YYU"!N8(`
M@+D:`$CL?2"_`%7KA@`>``WK!P`;``RSP0`H[`<@.@56N0@`!+/-`$+C@/*X
M``3"BLIBP=:Y&@"!ZV8``@`,N00`&+F!`$:YYT"%N8(`C;D:`!CL8""_`%7K
MAP`>``WKU@`;``RSP0`H[-8@.@56N0@`T;/-`!+C@/+```3"BLIBP=:Y&@"%
MZW<``@`,N00`6+F!`!>YYQ"$N8(`@+D:`%CL?2"_`%7KA@`>``WK!P`;``RS
MP0`H[`<@.@56N0@`!;/-`%+C@/+(``3"BLIBP=:Y&@"$ZV8``@`,N00`2+F!
M`%:YYU"!N8(`C;D:`$CL8""_`%7KAP`>``WKU@`;``RSP0`H[-8@.@56N0@`
MU+/-`$+C@/+0``3"BLIBP=:Y&@"!ZW<``@`,N00`&+F!`$>YYT"%N8(`@+D:
M`!CL?2"_`%7KA@`>``WK!P`;``RSP0`H[`<@.@56N0@``;/-`!+C@/+8``3"
MBLIBP=:Y&@"%ZV8``@`,N00`6+F!`!:YYQ"$N8(`C;D:`%CL8""_`%7KAP`>
M``WKU@`;``RSP0`H[-8@.@56N0@`U;/-`%+C@/+@``3"BLIBP=:Y&@"$ZW<`
M`@`,N00`2+F!`%>YYU"!N8(`@+D:`$CL?2"_`%7KA@`>``WK!P`;``RSP0`H
M[`<@.@56N0@`!+/-`$+C@/+H``3"BLIBP=:Y&@"!ZV8``@`,N00`&+F!`$:Y
MYT"%N8(`C;D:`!CKAP`>``WL8""_`%7KU@`;``SLUB`Z!5:Y"`#1ZQ<``@`,
MN8$`&+GG$(3C</+P``2Y@@`(PGK*8L'6N1H`=>Q=(+\`5;D:`'#KA0`;``SL
MA2`Z!5:Y!``'N00`>.N&`!X`#;D(`'#K!@`"``RY@0`(N><`@>-@\O@`!+F"
M`-C":LIBP=:Y&@!D[$<@OP!5N1H`;>N$`!L`#.R$(#H%5KD$`-:Y!`!HZX4`
M'@`-ZU4``@`,N8$`6+GG4("Y@@"'N0@`;>/0\P``!,+:RF+!UKD:`-&Y&@#8
MZX0`'@`-[!8@OP!5ZT0``@`,ZW$`&P`,N8$`2.QQ(#H%5KGG0(6Y"`!]N8(`
MAN/0\P@`!,+:RF+!UKD:`-"Y&@#8[`<@OP!5ZV``&P`,[&`@.@56N0@`;>/0
M\Q``!,+:RF+!UKD:`-7K@0`>``VY!`!=ZQ$``@`,N8$`&+GG$-2Y@@!]N1H`
M5^QV(+\`5;D$`-7K5P`;``SL5R`Z!5;C@"`@``2Y&@"!P(H`````XX`@(``D
MZX``'@`-ZP```@`,N8$`"+F"`!"Y&@"@N8(`8>P:(+\`5>,0(!@`)+D(`%WK
M%P`"``S`6@````#L%R`A'E:Y"`"5P)H`````XY`@"``DN0@`L>.0\Q@`!,*:
MRF+!UKD$``FY&@`$ZT4`&P`,N1H`!NQ%(#H%5KD(`$"Y&@`T[!,@OP!5XQ`@
M```D[!L@OP!5XQ`@$``DLD\`$.L1`"``#;)/`!'5!_,@$"BG=``)XT#SF``$
MZV_S6``$!_3`Y?__[L?L*`!K`'SK?_`X`"3$&```04[C\/]@_W'C@!````*G
MA``_XQ`@``"4[!@`4P!^[!@`4#U^N00`HD&@H`'C$*```)3L&``&`'[L%O_X
M/7X;HN.P@````J>$`".Y!`!RN00`D[D4`*JY!`#8N00`2KD$`#>Y!``KP.7_
M__#I["8`"0!^01JP`)4]$`"GA``20=#0"..PT````J=T_^FG*0``XT#Q$``$
MZW_PV``$!_2YZ8`=02JP`>L1``,`"E`0D`#C0/$0``3K?_#8``0']*>H``"G
M]/^_IRD```?^!P<'!^N_\%@`)+)/`!#C\/]0_W'K$0`@``VR3P`1N00`LM('
M\*@0*$'0\*2Y!``]N00`*\#E____>.PH`"T`?,0H``!`QN,0\*0`%.L1``,`
M#>,0(```".,@$`@`!.,@$```).PH_^0`?$$0$`CC(!`(``3C(!```"3L)O_X
M`'RY!``]N00`*\#E____3NPF_]D`?+)/`!#K$0`@``VR3P`1U0?PJ!`HIW0`
M">-`\2``!.N_\0@`!`?TP.7__^WY!P<'!^MO\#``),#0```0'>/P_TC_<;)/
M`!#K$0`@``VR3P`1N00`0Z<X``#2!_"P$"CC$$```)3`%P```#VY^Q`3N00`
M%.,0T```B*<(``"GJ0``N00`0>,0\*``)+D$`+*R7@"AIQ3__D$P\*RY"0"D
MP.7___[Y["@`K`!\IP@``*<9``"Y!``RLEX`$Z<4__ZY"0`2N3$`&J>D`(A8
M@/"LQ)@``$`UXQ"P``"4[!@`^0!^[!@`]CU^N00`&Z?T``7L*``+/7Y!$!`!
MXR`0``"4[";_^`!^&QOL*@`"`-CLB!V\`U4:(>.`D```"+D6`"+`Y?__[CWC
M((```"3L*`#;`'SC,)````3C(/"L`!;C$+```)#K(@`#``WC(C````1"$"``
M03"P`;F4`!'L%@`3`'ZG]``3XQ`P``"00A`@`4$P,`%!("`!N90`$>P8``8`
M?NP6__(]?I(](`"G&0``XS#PH``$XS$P``"00C$@`:<;``'L-O_V`'RG*```
MLD\`$.L1`"``#;)/`!'5!_"P$"BY%``BIW0`DN-0\2@`!.MO\.@`!`?UZP'P
MH`!Z02`@`>,0\*``!.,0'___D.,0+___<NP6__(`?*?T_]C$F```/Y[C<)``
M``3C$'````*GA`!CN00`%Z<H``"G]``#&"CL@@`!`-A!$!`(XS`0```"IW3_
M]Z<J``.Y%``BZR(``P`-P!```$??XQ`0```2IX0`(+D$`#*Y!``GP.7__^S_
MXR"0```D["@`/0!\N10`>.P7``$`V>L1``,`#4$1(`#E2!````!0@/"LI_3_
M)<`0``!'N>5,$````<#E___M?[D$`&+L*``>`'RY!``WN10`>.M'``,`#<#E
M___L,+D$`";C8)```"2G]/_4IQ@``*?T_QNG*0`0IX@``*?T_[.G*/__I_3_
M9,#E___LF`<'ZV_P,``DLD\`$./P_L#_<>L1`"``#;)/`!'2!_$X$"CL*``)
M`'RY!`#2E0`@`*=T`!6R3P`0ZQ$`(``-LD\`$=4'\3@0**=T`)KC0/&P``3K
M;_%P``0'],#E___O*+D$`++L*/_H`'Q!@/"HN00`*\#E___NK.PH`&``?)4N
M(!.GA`!GIP@``$&@(!.Y!``=IRD``+)>`"&G%/_^N00`.J<9``"R7@`3IQ3_
M_KD)`!JY"0`M&B&G*@`"N10`(KD$`&W`Y?__[//CH/"@`"2Y!`"2ITG__Z<Y
M``'`4```#G?`Y?__[72Y!`!(N00`.:<I``'`Y?__[HOL*``-_WY8$/#`IRA`
M`,`;``#P`.P2`#"`=KD$`"G`Y?__[+FY!``IP.7__^N4N00`*\#E___N3^PF
M_Z8`?+D$`"O`Y?__[I>Y!``MP.7__^O"I_3_=.,0(!0`E.P8_XP`?NP6_Y4N
M?I4`(!6GA/^$I_3_CKD$`"G`Y?___TBG]/_3P.7__^O7Z[_P6``DQ!@``#XU
MX_#_8/]QN00`TKD$`+'C(!```!;`Y?__[D2Y!``][$(!^`#9IRD``<#E___N
M2NPH``X`?J<H``#C0/$0``2Y%``BZ[_P^``$!_3C(+```!;`Y?__[B98$"(0
MIRA``,`;``#P`.P2`!.`=N,@L```%L#E___N%E@0(A"E+Z``P!L``/``[!+_
MV&!VN00`+:<Y``+`Y?__[840(N-`\1``!*<J___KO_#X``2((``?N10`(@?T
MZY_P2``DLD\`$./P_UC^<>L1`"``#>-0\*`!<;)/`!'2!U``$"BY!`"30=#P
MH+D$`**Y!``]ITD/_\`@```-JL#E___KQ.PL`$@`?NP2__\`V+D4`+'C._"@
M`)"G,0#_IX0`.+D4`+*Y!`!+N00`+:<Y`"_`Y?__[,KL*``N`'S$&```/9CC
M(!```!;`Y?__[:ZY!`!;N00`3;D$`#K`Y?__[56R3P`0XR#PH`%QZQ$`(``-
MLD\`$=4'(``0**=T`![C0/$8`03KG_#P`00'].P6_\P`?L08```];>,@$```
M%L#E___M@[D$`$FY!``ZP.7__^L\I_3_U\#E___J]^OO\'``),08```]5>/P
M_V#_<>,@$```%L#E___M:,!0```-+L1(```]0L`P```-.L08```]4.OO\1``
M!`?Q!P?K;_`P`"3C\/]8_W'$V```/3+C(-```!;`8```#HG`Y?__[47`Y?__
M_\[C(-```!;`Y?__[3RY!`!6Y4CPH```P$````GXP#````T:P.7__^R>XT#Q
M&``$ZV_PV``$!_3K;_`P`"2R3P`0X_#_2/UQZQ$`(``-XR#PL`)QLD\`$=('
M(``0*,#E___K,<`0```-"$'0\*ZY!`!BP%````S[N00`+>,0\*``)*=)$`&G
M.0`!P.7__^O+["0`10!^N00`+>.@\*\!<:=)$`"Y!``ZP.7__^K<N00`TNPD
M`#0`?J<J``&Y%``BP.7__^L@N00`LNPH`"@`?+D4`-VY!``ZN00`3<#E___I
M\D$=L`"Y!``KD@`0`+)/`!#C,/"P`G'K$0`@``VR3P`1U0<P`!`HIW0`#>-`
M\2@"!.MO\.@"!`?TIRD``*?T_^C`Y?__ZB_`]/___X@'!^MO\#``)+)/`!#C
M\/]`_G'K$0`@``WC0/"X`7&R3P`1T@=``!`HN00`TKD$`+/`(```#(Y!,/"T
MP.7___M(ISD`+[D$`**Y!``MP.7__^L#["@`(P!\N00`/<`@```,?<#E___\
M!+D$`"VR3P`0XS#PN`%QZQ$`(``-LD\`$=4',``0**=T`,GC0/$P`03K;_#P
M`00']*<(``"Y!``=N00`*Z>)``#`,```#%ZR7@"!IQ3__KGYT+C`Y?__Z]SL
M*/_,`'SLBP`!`-C`D```##]!</"XE0`@`+GB@"GLJ``/`'RG"```N00`$KD$
M`#JR70`3IQ3__J>$`&JY!``2IP@``*<Y``"R7@`QIQ3__KD)`#(8$[D4`#/C
M,R___W&5+S``IW0`$:<:__^Y%``Q04,@`)(`0`#C,R___W&5+S``IX3_\QH8
MIS@/_^P3_X8@=N/0\*@`),`0```,!^,0\*``)*=)$`"G.0`!N00`8L!0```,
MB+D$`"?`Y?__ZKS$N```.\WC(+```!;`Y?__Z^.Y!``W[$(!^`#9IRD``<#E
M___KR>PF`!,`?N,@L```%L#E___KT%@0(A"E+X``P!L``/``[!(`$(!VP#``
M``O,IRD``,#E___K3NPF_WT`?*?T_SNY!``GISD``<#E___K,NPF_^P`?KD$
M`#?`(```"ZS`Y?__^S.Y!``GP.7__^JBI_3_+,#E___I'0<'!P?`4```"TCC
M$"```)#L&``3`'P804$0(`&]05``XS`0``"0N>*`(1A#IQL``>PV__8`?`?^
M!P<'!^OO\'``)./P_V#_<>PH`#$`?.,P(```E.PX`"L`?J<(``"G&0``N00`
M0K)>`!2G%/_^XQ`?__]Q["$`0:!EE2\0`*=T`"RYZ2!!XQ`?__]QIT<`(>PX
M``TO?L`@```+6<08```[1.OO\1``!`?QIRD``L#E___I@^PH`&``?.5$(``N
M`.-`\1``!.OO\1``!`?TE2\0`*>$_]JYZ2!!XU`?__]Q["4`4R!E["@`4/]\
MXQ`?__]QIT<`->PA_\V`9+GI($'C,!___W'L(P!$(&7L*`!!_WSC$!___W&G
M1P`HN0D`$J=)$`#L,0`"`-GL-``E(&6Y!``R04`0`:=9$`#`(```.W#`Y?__
MZCG`(```.VKC0/$0``3K[_$0``0'])4O$`"G=/_&I_3_S)4O$`"GA/_3I_3_
MUJ<I``#C0/$0``3K[_$0``0']*=)``&G]/^QITD``:?T_\`'!P<'!P?KW_!H
M`"2R3P`0ZQ$`(``-LD\`$>/P_S#_<<`@```*RM('\,@0*,`0```*:M(A\*80
M`,#E___YW\`@```*P$'0\*#`Y?__^=?`(```"KS`Y?__^='`(```"KO`Y?__
M^<O`(```"KG`Y?__^<7`(```"KO`Y?__^;_`(```"HW`Y?__^;G`(```"K7`
MY?__^;/`(```"K3`Y?__^:W`(```"K/`Y?__^:?`(```"GK`Y?__^:'`(```
M"JS`Y?__^9O`(```"JO`Y?__^96Y!``]P"````JIP.7___D=["@`"P!\N00`
M,L`@```*B<#E___YXKD$`#W`(```"I_`Y?__^0KL*``+`'RY!``RP"````J=
MP.7___G/N00`/<`@```*F\#E___X]^PH`"<`?+D$`#+`(```"C#`Y?__^;S`
M,```"J'`(```"D?`Y?__^;.R3P`0ZQ$`(``-LD\`$=4'\,@0**=T`#7C0/%`
M``3KW_$X``0']+D$`#W`(```"G3`Y?__^,CL*``-`'RY!``RP"````HOP.7_
M__F-I_3_T:=)``K`,```"FA!(/"WP.7__^G5[";_Q0!^03#PP<`@```*&,#E
M___Y=J?T_[K`Y?__YV4'!P<'Z^_P<``DLD\`$./P_U#_<>L1`"``#;)/`!'$
M+0``.CO2!_"H$"CL*``8_WZR3P`0ZQ$`(``-LD\`$=4'\*@0*+D4`"*G=``K
MXT#Q(``$Z^_Q(``$!_1!,/"DP"````G>P.7___AL["@`%@!\XQ`@``"0[!@`
M$`!\P!<````PN0,`(>LB`#\`#,0O```Z!*?T_\^G*```I_3_^<#E___G$^OO
M\'``)./P_V#_<<#E___G&L#E___F=^PH``T`?.,@(```!.-`\1``!.OO\1``
M!`?TIRD``*?T__<'!P<'!P?K;_`P`"2Y!`#OX_#_`/]QI^O_^&"`X`"R3P`0
MZQ$`(``-LD\`$=('\/`0*,`0```Y=M(W\+@0`..P\+@``J>$`#JY!`"20=#P
MP$&`\+3`<```"5*G]``1N00`.<#E___F`NPH`#T`?*?;``CCL-_X_P*GA``@
MN00`.+D$`"O`Y?__]^VY!`"B["@`!P!\E0`@`*=T_^.Y!``KN00`.:?;``C`
MY?__^*OCL-_X_P*G=/_DLD\`$.L1`"``#;)/`!'5!_#P$"BG=`!!:(#P^.-`
M\7``!.MO\3``!`?TIP@``+D$`!FR7@`AIQ3__KD$`#JG&0``LEX`$Z<4__ZY
M"0`:N0D`*4$B$`*Y!`!IP.7__^<JXZ#PJ``DXW#PH``DL\$`@L!0```)=J=)
M__^G.0`!P.7__^>HL\T`.+D$`"O`Y?__^%VG]/^2P.7__^9,!P?K;_`P`"3`
MT```"(FY!`#OX_#]X/=QI^O_V&"`X`!@H.`(8,#@$&#@X!A@D.`@LD\`$.L1
M`"``#;)/`!'C,/'P"'%!</#,N00`LM(',``0*,`0```XV-(7\-`0`,`0```X
MWM(O\0`0`,`0```X\-(7\.@0`+D$`#?`(```"(G`Y?__]T7L*``'`'R5`"``
MIW0":,#E___^[[D$`(+L*`)M`'RG"```IRD``+D$`!BR7@`AIQ3__KD)`"CK
M(@`!``VG*P`!P.7__^:FXQ"```"0N00`HKD$`)(88>P8`!P`?+D$`"FYA`!F
MP%````CGITG__Z<Y``%!@(`!09"0`L#E___G&>,0@```D!AA[!;_Z@!\01#Q
M".,@\0```KD$`(&G=``+I_0`)Z>+``CC((_X_P*GA``@N00`-\#E___VY[D$
M`)+L*/_R`'R5`"``IX3_[<#E___YR^PH_^@`?KD$`"G`Y?__YQ>Y!`!B["8`
M.@!\XQ#PT``"IX0`,J>8``&Y!`"!E0`0`*=T`!:G]``HN10`&>L1``,`#>,1
M\-```KD$`(&GA``<IYH``94`$`"GA``6N00`*,#E___YF.PH_^D`?KD$`"C`
MY?__YN3L*/_A`'RY!`!BI_0`!*=I``"G"```N00`%J>9``"R7@"1IQ3__KD$
M`"JG&0``N0D`EK)>`!*G%/_^N0D`&AJ1IYH$!+D4`"FY!`"2P(````?%P.7_
M_^7XXZ#PL``DXX#PH``DP!````A*XQ#PJ``DL\$`HJ<Y``'`4```"#NG2?__
MP.7__^9PL\T`*J<Y`<#`Y?__YHGL*`!5_W[$&```-W>Y!`!AXR`0```6P.7_
M_^>+L\T`.NQ"`?@`V:<I``'`Y?__YY'L*`!A`'ZSS0!JQ!@``#=5XU"P```$
MP$````A-XR`0```$ISD``<#E___FRZ<I``"R3P`0XS#Q\`AQZQ$`(``-LD\`
M$=4',``0**=T!!3M@/'X"&7MH/(`"&7MP/(("&7MX/(0"&7MD/(8"&7C0/*0
M"`3K;_)0"`0'],#E___F`5@0(`#L&/^I$7ZSS0!JN10`$>-0L```!.,0\*``
M),08```W"\!````'RN,@$```!*<Y``'`Y?__YH2G*0``I_3_N>,@8```%L#E
M___G&E@0(A"G*$``P!L``/``[!+_E6!VXR!@```6P.7__^<*6*`B%,#E___D
ME>RB_X=@=N,@8```%L#E___F_%@0(A"G*`'`P!L```'_[!+_=V!VN00`*<#E
M___E+;D$`#>SP0""P"````=RP.7___6?["@`_@!\XZ"P```$P.7__^7:N00`
M,KD$`"K`Y?__^BNY!`"B["@`[`!\IP@``*<9``"Y!``JLEX`$J<4__ZY"0`:
M[!P`'P-^N10`(<`P```'=N,BK_S_<;)=`#*G%/_^IW0`$.P8`N8$?J<:__RY
M%``1XQ&O__]QE2\0`*>$`MK`Y?___,#L)@`0`'ZY!``JISD``,#E___E1KD$
M`*(8LNPF`+,`?L`P```'`<`@```&M;/-`&K`L```!\;`Y?__]@[`Y?__Y)_C
M(/"H`"2SS0`HXX#PH``DX[#PL``DP%````<[ITG__Z<Y``'`Y?__Y3JG&```
M&*&G]``KP.7__^4BU0/0`"``IW0`+;/-`&JGJ@`!P.7__^1VXR#PJ``DL\T`
M*+D4`!KCL/"X`"3C@/"@`"3`4```!Q?C$/"P`"2G2?__ISD``<#E___E#+/-
M`"BG.0'`P.7__^4E["C_T/]^L\T`*L#E___C/;/-`#C`(```!B7`Y?__];&S
MS0`HP.7___RPL\T`**?T_K6Y!`"BP.7___RGN00`*L#E___E$J?T_JE!H/#H
MXQ"@```"IX0`'[D$`#?C(*````3`Y?__]+WL*``'`'R5`"``IW0`!J>K``BG
M]/_JP.7__^3S["C_^0!\N00`@J?T_72G*0`-P(````9VI_3]?N.@L```!*?T
M_Q2G20`"ISG_[D%P\?#`Y?__X]>Y!``JN00`-Z=)``;`Y?__XJZ5`/'PIW0`
M!I5#\?&GA`)5N10`&[D$`"JSP0#!ITD``*<Y``!!8/$PP.7__^.WP!%G12,!
MXQ#Q,``DP!_OS:N)XQ#Q.``DP!^8NMS^XQ#Q0``DP!$0,E1VXQ#Q2``DP!_#
MTN'PY4CQ6```XQ#Q4``DY4CQ8```01#Q:.5,\:@``+/!`.&SS0`LN00`-Z5/
M@`#`Y?__XF.Y!`"2&*+L+`"<`'ZY%``IXS#Q6``$ZQ(``P`-N0@`$\`:````
M`.PQ`9@@9>,P\6``!.,0\5@`).LB`!T`#+GH,!+C$/%@`"3C$/&H`!*GA`&`
MIR@`0+GY$**SS0`N&9JY\L"IN1@`(;D$`#>Y%`"ZN00`2\#E___B9A@:6A#Q
MJ%`0\:CL%O^U0'ZY!``FN?F@J4&[<`#`Y?__YUWLK`&,/W[LFO_``-B(D``&
MN18`&:<;``'K$0`&``WC(!_`_W%!$;``X[#PP``DL\$`D>L2``8`#*<;``&Y
M!`"QXQ#PP``$N00`)M(_\6@0`.M`\,``>L#E___G+Z>W__*GJO_`B9``!ANI
ML\T`.;/-`"ZY%`!*IUD`2,#E___C5;/-`"Q0H/&HN00`-Z5/@`#`Y?__X<JY
M!`"2&*+L(O]J`'ZSS0`LP.7__^4/XQ#Q6``$X[#Q8``$["$ZOWU5N00`H;D4
M`!)!$?%HDH`0`*<J``'L(@$G.'ZSS0`>IS@`.+D8`!*Y^2`C["@`'@!^IRK_
M_^LR``@`WNPX`!$`?KD$`$KC(!0``#;7_Q``$`!!$!$`IS;_^+D$`*2Y%@`B
MQB````%A0K#QHT*@\:?K&P`8``Q"$/&@ZQL`$``,0A#QH>L:`!``#$(0\:7K
M.@`8``Q",/&DZQH`"``,0A#QIKD$`";KNP`(``Q"L/&B0;#QQT&@\;2Y!`";
MP.7__^:>XQ#Q,``$0A#QMNLA`!``#$(@\;3K(0`(``Q"(/&UZV$`&``,XQ#Q
M.``$0A#QNNLA`!@`#$(@\;?K(0`0``Q"(/&XZQ$`"``,0A#QN>,0\4``!$(0
M\;[K(0`8``Q"(/&[ZR$`$``,0B#QO.L1``@`#$(0\;WC$/%(``1"$/'"ZR$`
M&``,0B#QO^LA`!``#$(@\<#K$0`(``Q"$/'!XQ#Q4``$ZR$`&``,0A#QQD(@
M\</K(0`0``SK$0`(``Q"8/&S0A#QQ4(@\<2G&0`4N00`L;D$`"FYA`!FIYL`
M`L!0```$F*=)__^G.0`!P.7__^+.I[<`+;/-`&JSS0`H01#QQY(`\>_C$/"H
M`"3`$```!2_C@/"@`"3`4```!*KC$/"P`"2G2?__ISD``<#E___BKJ?T_:RY
M!`"WI_3^I>,P\6``!*<[``&G]/YI0V"@`*>K``&G]/^_XR"P"``"IX3]):<(
M``"G&0``N00`,K)>`!.G%/_^N0D`$NP<_1<#?>,Q+_S_<<`0```$<+)=`!.G
M%/_^N>*`HJ?T_0BSP0";I_3^I[/-`#ZG&`!`N1@`,KGY("'L*``@`'ZG*O__
MN00`$^LR``@`WNPX`!$`?KD$`$KC(!0``#;7_Q``$`!!$!$`IS;_^+D$`*2Y
M%@`BQB`````^N00`)L#E___EH-<W\6CQ:*?T_M*50?'RIW3]JY5#\?.G=/VG
ME4CQ]*=T_:.51?'UIW3]GZ=)``*G.?_&N00`*K/-`&K`Y?__X5BY!``JN00`
M-Z=)`"G`Y?__X"^SS0`HXW#PJ``DI_3_6<#E___@Q=<`$``0`-<`$``0`.MO
M\#``)+)/`!#K$0`@``VR3P`1X_#_4/]QQ)@``#,3T@?PJ!`HXR"0```606#P
MI,#E___C)+D$`#:2`2"QP"````,ZP.7___'6["@`!P!\E3$@`*>$`43`Y?__
M^$3C()```!;`Y?__XPJG60`+ITD``<`P```$&,#E___A4.PH`'D`?.,0(!``
M!.-P$"@`!,`0```[<.5<$````:?$`&JGJ```I]@``:?T`!?C("`0``2G"```
MLET`**<4__ZG=`!0IZH``:?:``'$'0``.U/L'0!*P';C()```!;`Y?__XLZY
M!``WIUD``+D4`$K`Y?__XF6Y!`"R["@`,P!\Q#@``#LUN10`'>L1``,`#>,@
M(```!..!,```!%@0(`RG.`0`P!L`(`0`[!/_PH!VXR"0```6P.7__^*BXS"P
M```$IUD``J=)``#`Y?__X&BG"```LET`**<4__ZGA/^TQ!T``#L)["'__P#8
M["H`H(!VXR"0```6P.7__^*!IUD``Z=)``'`,````Y+`Y?__X,>Y!`#2["@`
M'P!\XR"0```6P.7__^)LXQ#0$``$P$````-_XS`0```$P.7__^`@XQ#0$``$
MXQ`0```$D4`0#:=T`1;C()```!;`Y?__XE"G60`#ITD``<`P```#9<#E___@
MEKD$`-+L*``A`'RY!``VP"````(^P.7___#UN00`LN,@D```%NRX`+(`?,#E
M___B+N,0T!``!+D$`$OC,!````3`Y?__W^/C()```!;`Y?__XAV2`""QN00`
M-L`@```"$\#E___PS\0K```ZD+D$`++L*`!#`'RG.0'`P.7__^#V["@`"1%^
M[!(``0#8[!(`V`%_LD\`$.L1`"``#;)/`!'5!_"H$"BG=`#(XT#Q(``$ZV_P
MX``$!_3L'/]C`7ZGV``!XR"0```6I]H``<#E___AW;D$`#?`Y?__WPC&W0``
M.E&G1/_PI_3_3)4`(`&GA/Z_I_3^NL0H```Z0,#E___X_<0K```Z0NPH`)$`
M?.,0T!``!*<X!`#C$!````18(!`,P"L`(`0`[",`6V!VXR`0$``$Q+@``#HA
MN00`.\#E___>Y.,0T!``!+D$`*+C$!````3CL+````18(!`,IS@$`,`K`"`$
M`.PC`"1@=N-`$!``!+D$`%JY!``[P"````*SP.7__^!BP.7__^%_Q"@``#GT
MXQ#0$``$XS`@```$XR`0```$P.7___-\I_3_3>,@D```%L#E___A:.,0T!``
M!*=)``"G60`"XS`0```$P.7__]\KN00`0J?T_\WC()```!;`Y?__X5'C$-`0
M``2G60`"ITD``.,P$```!,#E___?%*?T_YCC()```!;`Y?__X3SC$-`0``3C
M,!````3`Y?__X&.G]/[=P"````)+P.7__^`+P.7__]ZHQ!@``#F=N00`4KD$
M`$O`(````F#C,!````3`Y?__W_@'!^NO\%``),#0````V>/P_V#_<;D$`++`
MY?__]8VY!`"BXQ`@``"0[!@`$P!\&#%!$"`!O3'0`.,@$```D+GB@*$8,J<;
M``'L)O_V`'S`Y?__]P[L*``5`'[LN``2`'R5`+``IX0`#;D$`"K`,````7K`
MY?__W9SLH@`*@&3C0/$0``3KK_#P``0']+D$`"OKK_#P``3`]/__\;8'!P<'
M!P?`$```,-RY`@`1IX0`#.-0$```!,`0```PIN,0$```!`?QP!```#"?P%``
M`##(XQ`0```$!_$'!^N/\$``)*?[_V"Y!`"RN00`H[D$`)3`Y?__W2W`T```
M+G;`$```+F^Y"0#1Z]T``P`*IX0`$KD$`('C$(````2Y!``KN00`.KD$`$FG
MBP`(#>&GU__TXT#Q$``$ZX_PX``$!_0'!P<'!_X'!P<'!P?K;_`P`"2Y!``?
MI_O_8.,0\```),#````O2@<'XT#Q$``$ZV_PT``$!_0'!P```````@`!````
M````````````+P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M`````````!$`````+P!P97)L>'-I+F,``````"5S+R5S`"]P<F]C+W-E;&8O
M97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI0
M05(Z.D)/3U0``"]P<F]C+R5I+R5S`&5X90`N`%!!4E]414U0``!005)?4%)/
M1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T%21T,``%!!4E]!4D=67S```%!!4E]'3$]"
M04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``!005)?0TQ%04X]```Q`$Q)
M0E!!5$@`3$E"4D%265]0051(``!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0
M051(``!365-414T``"4P,G@``"5S)7,E<R5S``!P87(M```E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*``!P87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*```O=&UP``!414U01$E2`%1-4`!54T52``!54T523D%-
M10``05)'5@``&`!P97)L```P`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T
M;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M
M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D
M7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%2
M7T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P
M<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL
M92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS
M965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F
M+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z
M("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H
M)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F
M9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E
M="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D
M:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I
M;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM
M;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R
M:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H
M)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC
M<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D
M9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G
M/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O
M<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I
M;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE
M;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L
M<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P
M96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A
M<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D
M92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\
M4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV
M>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR
M97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@
M/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA
M+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`````!&P,[````T```
M`!G__X`<```%?/__@\P```#L__^<]````2S__YW4```!A/__GI0```&T__^A
M5````?3__Z+4```"-/__HY0```)L__^DE````J3__Z34```"Q/__I30```,$
M__^F)````T3__Z8L```#7/__J$P```.<__^HA````[3__ZGD```#]/__J[P`
M``0<__^L7```!$3__ZR<```$;/__K>P```2L__^Y!```!/S__[U4```%//__
MO?0```6\__^^+```!=3__[Z4```&#````!0``````7I2``%X#@$;#`^@`0``
M`````#P````<__^"V```&2@`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[(!P,9
M$`K/SLW,R\K)R,?&#J`!0@L```````!4````7/__F\````#<`%*'#8@,B0N*
M"HL)C`B-!XX&CP5&#L`"`I0*S\[-S,O*R<C'#J`!0@M>"L?(R<K+S,W.SPZ@
M`4(+2`Z@`<?(R<K+S,W.SP``````+````+3__YQ(````O`!*BPF,"(T'C@:/
M!48.T`("I`K/SLW,RPZ@`4(+````````/````.3__YS8```"O@!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5,#M@"`P&2"L_.S<S+RLG(Q\8.H`%""P```````#P`
M``$D__^?6````8``2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`P)&"L_.S<S+
MRLG(Q\8.H`%""P`````````T```!9/__H)@```#``$R+"8P(C0>.!H\%1@[`
M`@)""L_.S<S+#J`!0@L"8,O,S<[/#J`!`````#0```&<__^A(````0``2HD+
MB@J+"8P(C0>.!H\%1@[((@*^"L_.S<S+RLD.H`%""P``````````'````=3_
M_Z'H````/@!,C@:/!48.P`)JS\X.H`$````\```!]/__H@@```!@`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.R`("4L_.S<S+RLG(Q\8.H`$`````````````
M/````C3__Z(H````\`!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#MA"`M`*S\[-
MS,O*R<C'Q@Z@`4(+`````````!0```)T__^BV`````8``````````````#P`
M``*,__^BR````AP`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@(@*$"L_.S<S+
MRLG(Q\8.H`%""P`````````4```"S/__I*@````T```````````````\```"
MY/__I,@```%:`$:.!H\%1@[``@)@"L_.#J`!0@MB"L_.#J`!0@L"C`K.SPZ@
M`4(+:`K.SPZ@`4(+````)````R3__Z7H```!U`!4C0>.!H\%1@[P`@,!6@K/
MSLT.H`%""P```"0```-,__^GF````*``2HX&CP5&#M`"`D0*S\X.H`%""P``
M```````D```#=/__J!`````Z`$:.!H\%1@[``F0*S\X.H`%""P``````````
M/````YS__Z@H```!3@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#J`#2)@5`L(*
MS\[-S,O*R<C'QM@.H`%""P```$P```/<__^I.```"Q@`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%4`[`A0)8F!F9&)H7FQ:<%0,"W@K/SLW,R\K)R,?&W-O:V=@.
MH`%""P``````/```!"S__[0````$3@!4A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#M`"`P*."L_.S<S+RLG(Q\8.H`%""P```````#P```1L__^X$````)H`1HH*
MBPF,"(T'C@:/!4P.P`("=@K/SLW,R\H.H`%""TK/SLW,R\H.H`$`````````
M```\```$K/__>I@```)<`%2&#H<-B`R)"XH*BPF,"(T'C@:/!48.Z`(#`;(*
MS\[-S,O*R<C'Q@Z@`4(+````````%```!.S__[@P````-@``````````````
M-```!03__[A0````9`!&B`R)"XH*BPF,"(T'C@:/!40.P`("6,_.S<S+RLG(
M#J`!```````````4```%//__N(`````"````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````)D@````````E^```````````````````
M``$``````````0`````````!`````````<0``````````0````````(3````
M``````P````````;6``````````-````````85@`````````&0```````+WH
M`````````!L`````````"``````````:````````O?``````````'```````
M```(`````&___O4````````"D``````````%````````#-``````````!@``
M``````-P``````````H````````$L``````````+`````````!@`````````
M%0````````````````````,```````#````````````"````````!5@`````
M````%``````````'`````````!<````````6```````````'````````$K@`
M````````"`````````-(``````````D`````````&`````!O___[``````@`
M````````;____@```````!)(`````&____\``````````@````!O___P````
M````$8``````;___^0`````````4````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"^```````````````````````````````;Q@``
M`````!OF````````'`8````````<)@```````!Q&````````'&8````````<
MA@```````!RF````````',8````````<Y@```````!T&````````'28`````
M```=1@```````!UF````````'88````````=I@```````!W&````````'>8`
M```````>!@```````!XF````````'D8````````>9@```````!Z&````````
M'J8````````>Q@```````![F````````'P8````````?)@```````!]&````
M````'V8````````?A@```````!^F````````'\8````````?Y@```````"`&
M````````("8````````@1@```````"!F````````((8````````@I@``````
M`"#&````````(.8````````A!@```````"$F````````(48````````A9@``
M`````"&&````````(:8````````AQ@```````"'F````````(@8````````B
M)@```````")&````````(F8````````BA@```````"*F````````(L8`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(M@`````````````````````````````````````````````````````````
M````PF@```````!C.@```````&,B````````8RH```````!C4````````&,X
M````````8TH``````````````````&1`````````8C``````````````````
M`&+F````````8NH```````!D1@```````&(V````````9$X`````````````
M`````&12````````9%@``````````/____\`````````````909'0T,Z("A5
M8G5N='4@-2XS+C$M-G5B=6YT=3$I(#4N,RXQ(#(P,38P,3$T`$=#0SH@*%5B
M=6YT=2`T+CDN,RTX=6)U;G1U,2D@-"XY+C,``"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M```````````````````````````+`````0`````````"`````````C@`````
M```".``````````/`````````````````````0``````````````$P````<`
M`````````@````````)(`````````D@`````````(```````````````````
M``0``````````````"$````'``````````(````````":`````````)H````
M`````"0````````````````````$```````````````T;___]@`````````"
M`````````I`````````"D`````````#<````!0``````````````"```````
M````````/@````L``````````@````````-P`````````W`````````)8```
M``8````"``````````@`````````&````$8````#``````````(````````,
MT`````````S0````````!+`````````````````````!``````````````!.
M;____P`````````"````````$8`````````1@`````````#(````!0``````
M`````````@`````````"````6V____X``````````@```````!)(````````
M$D@`````````<`````8````"``````````@``````````````&H````$````
M``````(````````2N````````!*X`````````T@````%```````````````(
M`````````!@```!T````!`````````!"````````%@`````````6````````
M``58````!0```!8`````````"``````````8````?@````$`````````!@``
M`````!M8````````&U@`````````0`````````````````````0`````````
M`````'D````!``````````8````````;F````````!N8````````!T``````
M```````````````$`````````"````"$`````0`````````&````````(M@`
M```````BV````````#Z`````````````````````"```````````````B@``
M``$`````````!@```````&%8````````85@`````````+```````````````
M``````0``````````````)`````!``````````(```````!AB````````&&(
M````````03(````````````````````(``````````````"8`````0``````
M```"````````HKP```````"BO`````````#4````````````````````!```
M````````````I@````$``````````@```````*.0````````HY`````````%
M5`````````````````````@``````````````+`````.``````````,`````
M``"]Z````````*WH``````````@````````````````````(````````````
M``"\````#P`````````#````````O?````````"M\``````````(````````
M````````````"```````````````R`````$``````````P```````+WX````
M````K?@`````````"`````````````````````@``````````````,T````&
M``````````,```````"^`````````*X``````````@`````&````````````
M```(`````````!````#6`````0`````````#````````P`````````"P````
M``````)@````````````````````"``````````(````VP````$`````````
M`P```````,)@````````LF``````````N`````````````````````@`````
M`````````.$````(``````````,```````##&````````+,8````````$#``
M```````````````````(``````````````#F`````0`````````P````````
M``````````"S&`````````!/`````````````````````0`````````!````
M`0````,`````````````````````````````LV<`````````[P``````````
0``````````$`````````````
